@@ -1,36 +1,50 @@
 package GIS::Distance;
-{
-  $GIS::Distance::VERSION = '0.08';
-}
-
+$GIS::Distance::VERSION = '0.09';
 =head1 NAME
 
 GIS::Distance - Calculate geographic distances.
 
 =head1 SYNOPSIS
 
-  use GIS::Distance;
-  
-  my $gis = GIS::Distance->new();
-  
-  $gis->formula( 'Polar' );  # Optional, default is Haversine.
-  
-  my $distance = $gis->distance( $lat1,$lon1 => $lat2,$lon2 );
-  
-  print $distance->meters();
+    use GIS::Distance;
+    
+    my $gis = GIS::Distance->new();
+    $gis->formula( 'Polar' );  # Optional, default is Haversine.
+    
+    # Or:
+    my $gis = GIS::Distance->new( 'Polar' );
+    
+    my $distance = $gis->distance( $lat1,$lon1 => $lat2,$lon2 );
+    
+    print $distance->meters();
 
 =head1 DESCRIPTION
 
-This perl library aims to provide as many tools to make it as simple as possible to calculate
-distances between geographic points, and anything that can be derived from that.
+This module calculates distances between geographic points on, at the moment,
+plant Earth.  Various formulas are available that provide different levels of
+accuracy versus calculation speed tradeoffs.
+
+All distances are returned as L<Class::Measure> objects.
 
 =cut
 
-use Any::Moose;
-use namespace::autoclean;
+use Types::Standard -types;
+use Type::Utils -all;
 
-use Any::Moose '::Util::TypeConstraints';
-use Carp qw( croak );
+use Moo;
+use strictures 1;
+use namespace::clean;
+
+around BUILDARGS => sub{
+    my $orig = shift;
+    my $class = shift;
+
+    if (@_==1 and ref($_[0]) ne 'HASH') {
+        return { formula => $_[0] };
+    }
+
+    return $class->$orig( @_ );
+};
 
 =head1 METHODS
 
@@ -62,8 +76,8 @@ exists will be created and used:
   GIS::Distance::Formula::Haversine
   Haversine
 
-If you are using your own custom formula class make sure it extends() (L<Moose>)
-the L<GIS::Distance::Formula> class.
+If you are using your own custom formula class make sure it applies
+the L<GIS::Distance::Formula> role.
 
 Note that a ::Fast version of the class will be looked for first.  By default
 the ::Fast versions of the formulas, written in C, are not available and the
@@ -72,36 +86,34 @@ then install L<GIS::Distance::Fast> and they will be automatically used.
 
 =cut
 
-subtype 'GISDistanceFormula'
-    => as 'Object';
+my $formula_type = declare 'GISDistanceFormula',
+    as HasMethods[ 'distance' ];
 
-coerce 'GISDistanceFormula'
-    => from 'Str'
-        => via {
-            my $class = $_;
-            foreach my $full_class (
-                "GIS::Distance::Formula::${class}::Fast",
-                "GIS::Distance::Formula::$class",
-                $class,
-            ) {
-                eval( "require $full_class" );
-                if (!$@) {
-                    return $full_class->new();
-                }
-            }
-            die( qq{The GIS::Distance formula "$class" can not be found} );
-        };
+coerce $formula_type,
+    from Str,
+    via {
+        my $class = $_;
+        foreach my $full_class (
+            "GIS::Distance::Formula::${class}::Fast",
+            "GIS::Distance::Formula::$class",
+            $class,
+        ) {
+            local $@;
+            my $success = eval( "require $full_class; 1" );
+            return $full_class->new() if $success;
+            die $@ if $@ !~ m{^Can't locate};
+        }
+        die( qq{The GIS::Distance formula "$class" cannot be found} );
+    };
 
-has 'formula' => (
+has formula => (
     is      => 'rw',
-    isa     => 'GISDistanceFormula',
+    isa     => $formula_type,
+    coerce  => 1,
     default => 'Haversine',
     handles => ['distance'],
-    coerce  => 1,
 );
 
-__PACKAGE__->meta->make_immutable;
-
 1;
 __END__
 
@@ -153,23 +165,6 @@ very useful info is at L<http://en.wikipedia.org/wiki/Geoid>.
 Both the L<GIS::Distance::Formula::GreatCircle> and L<GIS::Distance::Formula::Polar> formulas are
 broken.  Read their respective man pages for details.
 
-=head1 TEST COVERAGE
-
-  ---------------------------- ------ ------ ------ ------ ------ ------ ------
-  File                           stmt   bran   cond    sub    pod   time  total
-  ---------------------------- ------ ------ ------ ------ ------ ------ ------
-  blib/lib/GIS/Distance.pm      100.0    n/a    n/a  100.0  100.0   24.0  100.0
-  ...b/GIS/Distance/Formula.pm   75.0    n/a    n/a   66.7  100.0    1.9   75.0
-  ...istance/Formula/Cosine.pm  100.0    n/a    n/a  100.0  100.0    5.9  100.0
-  ...e/Formula/GeoEllipsoid.pm  100.0    n/a    n/a  100.0  100.0    3.6  100.0
-  ...ce/Formula/GreatCircle.pm  100.0    n/a    n/a  100.0  100.0    5.9  100.0
-  ...ance/Formula/Haversine.pm  100.0    n/a    n/a  100.0  100.0    9.1  100.0
-  ...tance/Formula/MathTrig.pm  100.0    n/a    n/a  100.0  100.0    2.4  100.0
-  ...Distance/Formula/Polar.pm  100.0    n/a    n/a  100.0  100.0    2.7  100.0
-  ...tance/Formula/Vincenty.pm  100.0   50.0   50.0  100.0  100.0   44.6   93.1
-  Total                          98.8   50.0   50.0   97.2  100.0  100.0   96.7
-  ---------------------------- ------ ------ ------ ------ ------ ------ ------
-
 =head1 AUTHOR
 
 Aran Clary Deltac <bluefeet@cpan.org>
