@@ -1,8 +1,5 @@
 package GIS::Distance::Formula::Cosine;
-{
-  $GIS::Distance::Formula::Cosine::VERSION = '0.08';
-}
-
+$GIS::Distance::Formula::Cosine::VERSION = '0.09';
 =head1 NAME
 
 GIS::Distance::Formula::Cosine - Cosine distance calculations.
@@ -24,14 +21,15 @@ is used which in turn interfaces with the various formula classes.
 
 =cut
 
-use Any::Moose;
-use namespace::autoclean;
-
-with 'GIS::Distance::Formula';
-
 use Class::Measure::Length qw( length );
 use Math::Trig qw( deg2rad acos );
 
+use Moo;
+use strictures 1;
+use namespace::clean;
+
+with 'GIS::Distance::Formula';
+
 =head1 METHODS
 
 =head2 distance
@@ -52,8 +50,6 @@ sub distance {
     return length( $self->kilometer_rho() * $c, 'km' );
 }
 
-__PACKAGE__->meta->make_immutable;
-
 1;
 __END__
 
