@@ -1,8 +1,5 @@
 package GIS::Distance::Formula::GreatCircle;
-{
-  $GIS::Distance::Formula::GreatCircle::VERSION = '0.08';
-}
-
+$GIS::Distance::Formula::GreatCircle::VERSION = '0.09';
 =head1 NAME
 
 GIS::Distance::Formula::GreatCircle - Great circle distance calculations. (BROKEN)
@@ -33,14 +30,15 @@ this module unless you want to help fix it.
 
 =cut
 
-use Any::Moose;
-use namespace::autoclean;
-
-with 'GIS::Distance::Formula';
-
 use Class::Measure::Length qw( length );
 use Math::Trig qw( deg2rad asin );
 
+use Moo;
+use strictures 1;
+use namespace::clean;
+
+with 'GIS::Distance::Formula';
+
 =head1 METHODS
 
 =head2 distance
@@ -63,8 +61,6 @@ sub distance {
     return length( $self->kilometer_rho() * $c, 'km' );
 }
 
-__PACKAGE__->meta->make_immutable;
-
 1;
 __END__
 
