@@ -1,8 +1,5 @@
 package GIS::Distance::Formula::MathTrig;
-{
-  $GIS::Distance::Formula::MathTrig::VERSION = '0.08';
-}
-
+$GIS::Distance::Formula::MathTrig::VERSION = '0.09';
 =head1 NAME
 
 GIS::Distance::Formula::MathTrig - Great cirlce distance calculations using Math::Trig.
@@ -30,14 +27,15 @@ As stated in the L<Math::Trig> POD.
 
 =cut
 
-use Any::Moose;
-use namespace::autoclean;
-
-with 'GIS::Distance::Formula';
-
 use Class::Measure::Length qw( length );
 use Math::Trig qw( great_circle_distance deg2rad );
 
+use Moo;
+use strictures 1;
+use namespace::clean;
+
+with 'GIS::Distance::Formula';
+
 =head1 METHODS
 
 =head2 distance
@@ -61,8 +59,6 @@ sub distance {
     );
 }
 
-__PACKAGE__->meta->make_immutable;
-
 1;
 __END__
 
