@@ -1,8 +1,5 @@
 package GIS::Distance::Formula::Polar;
-{
-  $GIS::Distance::Formula::Polar::VERSION = '0.08';
-}
-
+$GIS::Distance::Formula::Polar::VERSION = '0.09';
 =head1 NAME
 
 GIS::Distance::Formula::Polar - Polar coordinate flat-earth distance calculations. (BROKEN)
@@ -31,14 +28,15 @@ the implementation is) as you can see in 02_polar.t.
 
 =cut
 
-use Any::Moose;
-use namespace::autoclean;
-
-with 'GIS::Distance::Formula';
-
 use Class::Measure::Length qw( length );
 use Math::Trig qw( deg2rad pi );
 
+use Moo;
+use strictures 1;
+use namespace::clean;
+
+with 'GIS::Distance::Formula';
+
 =head1 METHODS
 
 =head2 distance
@@ -57,8 +55,6 @@ sub distance {
     return length( $self->kilometer_rho() * $c, 'km' );
 }
 
-__PACKAGE__->meta->make_immutable;
-
 1;
 __END__
 
