@@ -1,8 +1,5 @@
 package GIS::Distance::Formula::Vincenty;
-{
-  $GIS::Distance::Formula::Vincenty::VERSION = '0.08';
-}
-
+$GIS::Distance::Formula::Vincenty::VERSION = '0.09';
 =head1 NAME
 
 GIS::Distance::Formula::Vincenty - Thaddeus Vincenty distance calculations.
@@ -69,14 +66,15 @@ is used which in turn interfaces with the various formula classes.
 
 =cut
 
-use Any::Moose;
-use namespace::autoclean;
-
-with 'GIS::Distance::Formula';
-
 use Class::Measure::Length qw( length );
 use Math::Trig qw( deg2rad pi tan atan asin );
 
+use Moo;
+use strictures 1;
+use namespace::clean;
+
+with 'GIS::Distance::Formula';
+
 =head1 METHODS
 
 =head2 distance
@@ -125,8 +123,6 @@ sub distance {
     return length( $c, 'm' );
 }
 
-__PACKAGE__->meta->make_immutable;
-
 1;
 __END__
 
